@@ -33,7 +33,7 @@ class TransactionPipeResultOptions(pydantic.BaseModel):
 class MessageTransaction(pydantic.BaseModel):
     fnc: Callable
     args: Optional[Dict]
-    pipe_result_options: Optional[Union, Callable]
+    pipe_result_options: Optional[Union[Callable, TransactionPipeResultOptions]]
 
 
 class MessagePipeline(pydantic.BaseModel):
